@@ -392,6 +392,30 @@ class MC(dict):
                       })
         return r["message"]
 
+    def get_cloudlet(self):
+        return self.call("ctrl/ShowCloudlet",
+                         data={
+                             "cloudlet": {
+                                 "key": {
+                                     "name": self.cloudlet,
+                                     "organization": self.cloudlet_org,
+                                 },
+                             },
+                             "region": self.region,
+                         })
+
+    def get_cloudlet_info(self):
+        return self.call("ctrl/ShowCloudletInfo",
+                         data={
+                             "cloudletinfo": {
+                                 "key": {
+                                     "name": self.cloudlet,
+                                     "organization": self.cloudlet_org,
+                                 },
+                             },
+                             "region": self.region,
+                         })
+
     def get_cluster_instances(self):
         return self.call("ctrl/ShowClusterInst",
                          data={
